# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scanner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/scanner.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/yandex/cloud/containerregistry/v1/scanner.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x02\n\nScanResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08image_id\x18\x02 \x01(\t\x12.\n\nscanned_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x06status\x18\x04 \x01(\x0e\x32\x34.yandex.cloud.containerregistry.v1.ScanResult.Status\x12N\n\x0fvulnerabilities\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.containerregistry.v1.VulnerabilityStats\"C\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"x\n\x12VulnerabilityStats\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x03\x12\x0c\n\x04high\x18\x02 \x01(\x03\x12\x0e\n\x06medium\x18\x03 \x01(\x03\x12\x0b\n\x03low\x18\x04 \x01(\x03\x12\x12\n\nnegligible\x18\x05 \x01(\x03\x12\x11\n\tundefined\x18\x06 \x01(\x03\"\xb1\x02\n\rVulnerability\x12K\n\x08severity\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.Vulnerability.Severity\x12J\n\x07package\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.containerregistry.v1.PackageVulnerabilityH\x00\"p\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\n\n\x06MEDIUM\x10\x03\x12\x07\n\x03LOW\x10\x04\x12\x0e\n\nNEGLIGIBLE\x10\x05\x12\r\n\tUNDEFINED\x10\x06\x42\x15\n\rvulnerability\x12\x04\xc0\xc1\x31\x01\"v\n\x14PackageVulnerability\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x0f\n\x07package\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x08\x66ixed_by\x18\x06 \x01(\tB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SCANRESULT_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.containerregistry.v1.ScanResult.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=393,
  serialized_end=460,
)
_sym_db.RegisterEnumDescriptor(_SCANRESULT_STATUS)

_VULNERABILITY_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='yandex.cloud.containerregistry.v1.Vulnerability.Severity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRITICAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEGLIGIBLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=755,
  serialized_end=867,
)
_sym_db.RegisterEnumDescriptor(_VULNERABILITY_SEVERITY)


_SCANRESULT = _descriptor.Descriptor(
  name='ScanResult',
  full_name='yandex.cloud.containerregistry.v1.ScanResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.containerregistry.v1.ScanResult.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.ScanResult.image_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scanned_at', full_name='yandex.cloud.containerregistry.v1.ScanResult.scanned_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.containerregistry.v1.ScanResult.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vulnerabilities', full_name='yandex.cloud.containerregistry.v1.ScanResult.vulnerabilities', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCANRESULT_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=151,
  serialized_end=460,
)


_VULNERABILITYSTATS = _descriptor.Descriptor(
  name='VulnerabilityStats',
  full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='critical', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.critical', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.high', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='medium', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.medium', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.low', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negligible', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.negligible', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undefined', full_name='yandex.cloud.containerregistry.v1.VulnerabilityStats.undefined', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=582,
)


_VULNERABILITY = _descriptor.Descriptor(
  name='Vulnerability',
  full_name='yandex.cloud.containerregistry.v1.Vulnerability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='severity', full_name='yandex.cloud.containerregistry.v1.Vulnerability.severity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package', full_name='yandex.cloud.containerregistry.v1.Vulnerability.package', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VULNERABILITY_SEVERITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='vulnerability', full_name='yandex.cloud.containerregistry.v1.Vulnerability.vulnerability',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=585,
  serialized_end=890,
)


_PACKAGEVULNERABILITY = _descriptor.Descriptor(
  name='PackageVulnerability',
  full_name='yandex.cloud.containerregistry.v1.PackageVulnerability',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.link', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='package', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.package', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.source', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fixed_by', full_name='yandex.cloud.containerregistry.v1.PackageVulnerability.fixed_by', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=892,
  serialized_end=1010,
)

_SCANRESULT.fields_by_name['scanned_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCANRESULT.fields_by_name['status'].enum_type = _SCANRESULT_STATUS
_SCANRESULT.fields_by_name['vulnerabilities'].message_type = _VULNERABILITYSTATS
_SCANRESULT_STATUS.containing_type = _SCANRESULT
_VULNERABILITY.fields_by_name['severity'].enum_type = _VULNERABILITY_SEVERITY
_VULNERABILITY.fields_by_name['package'].message_type = _PACKAGEVULNERABILITY
_VULNERABILITY_SEVERITY.containing_type = _VULNERABILITY
_VULNERABILITY.oneofs_by_name['vulnerability'].fields.append(
  _VULNERABILITY.fields_by_name['package'])
_VULNERABILITY.fields_by_name['package'].containing_oneof = _VULNERABILITY.oneofs_by_name['vulnerability']
DESCRIPTOR.message_types_by_name['ScanResult'] = _SCANRESULT
DESCRIPTOR.message_types_by_name['VulnerabilityStats'] = _VULNERABILITYSTATS
DESCRIPTOR.message_types_by_name['Vulnerability'] = _VULNERABILITY
DESCRIPTOR.message_types_by_name['PackageVulnerability'] = _PACKAGEVULNERABILITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ScanResult = _reflection.GeneratedProtocolMessageType('ScanResult', (_message.Message,), {
  'DESCRIPTOR' : _SCANRESULT,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ScanResult)
  })
_sym_db.RegisterMessage(ScanResult)

VulnerabilityStats = _reflection.GeneratedProtocolMessageType('VulnerabilityStats', (_message.Message,), {
  'DESCRIPTOR' : _VULNERABILITYSTATS,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.VulnerabilityStats)
  })
_sym_db.RegisterMessage(VulnerabilityStats)

Vulnerability = _reflection.GeneratedProtocolMessageType('Vulnerability', (_message.Message,), {
  'DESCRIPTOR' : _VULNERABILITY,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.Vulnerability)
  })
_sym_db.RegisterMessage(Vulnerability)

PackageVulnerability = _reflection.GeneratedProtocolMessageType('PackageVulnerability', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEVULNERABILITY,
  '__module__' : 'yandex.cloud.containerregistry.v1.scanner_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.PackageVulnerability)
  })
_sym_db.RegisterMessage(PackageVulnerability)


DESCRIPTOR._options = None
_VULNERABILITY.oneofs_by_name['vulnerability']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/oauth/claims.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/oauth/claims.proto',
  package='yandex.cloud.oauth',
  syntax='proto3',
  serialized_options=b'\n\031yandex.cloud.api.oauth.v1Z<github.com/yandex-cloud/go-genproto/yandex/cloud/oauth;oauth',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fyandex/cloud/oauth/claims.proto\x12\x12yandex.cloud.oauth\x1a\x1dyandex/cloud/validation.proto\"\x89\x02\n\rSubjectClaims\x12\x19\n\x03sub\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ngiven_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x1a\n\x12preferred_username\x18\x07 \x01(\t\x12\x0f\n\x07picture\x18\t \x01(\t\x12\r\n\x05\x65mail\x18\x0b \x01(\t\x12\x10\n\x08zoneinfo\x18\x0f \x01(\t\x12\x0e\n\x06locale\x18\x10 \x01(\t\x12\x14\n\x0cphone_number\x18\x11 \x01(\t\x12\x32\n\nfederation\x18\x64 \x01(\x0b\x32\x1e.yandex.cloud.oauth.Federation\"4\n\nFederation\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04name\x18\x03 \x01(\tBY\n\x19yandex.cloud.api.oauth.v1Z<github.com/yandex-cloud/go-genproto/yandex/cloud/oauth;oauthb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_SUBJECTCLAIMS = _descriptor.Descriptor(
  name='SubjectClaims',
  full_name='yandex.cloud.oauth.SubjectClaims',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sub', full_name='yandex.cloud.oauth.SubjectClaims.sub', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.oauth.SubjectClaims.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='given_name', full_name='yandex.cloud.oauth.SubjectClaims.given_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='family_name', full_name='yandex.cloud.oauth.SubjectClaims.family_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferred_username', full_name='yandex.cloud.oauth.SubjectClaims.preferred_username', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='picture', full_name='yandex.cloud.oauth.SubjectClaims.picture', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='yandex.cloud.oauth.SubjectClaims.email', index=6,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zoneinfo', full_name='yandex.cloud.oauth.SubjectClaims.zoneinfo', index=7,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locale', full_name='yandex.cloud.oauth.SubjectClaims.locale', index=8,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone_number', full_name='yandex.cloud.oauth.SubjectClaims.phone_number', index=9,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='federation', full_name='yandex.cloud.oauth.SubjectClaims.federation', index=10,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=352,
)


_FEDERATION = _descriptor.Descriptor(
  name='Federation',
  full_name='yandex.cloud.oauth.Federation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.oauth.Federation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.oauth.Federation.name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=354,
  serialized_end=406,
)

_SUBJECTCLAIMS.fields_by_name['federation'].message_type = _FEDERATION
DESCRIPTOR.message_types_by_name['SubjectClaims'] = _SUBJECTCLAIMS
DESCRIPTOR.message_types_by_name['Federation'] = _FEDERATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubjectClaims = _reflection.GeneratedProtocolMessageType('SubjectClaims', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECTCLAIMS,
  '__module__' : 'yandex.cloud.oauth.claims_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.oauth.SubjectClaims)
  })
_sym_db.RegisterMessage(SubjectClaims)

Federation = _reflection.GeneratedProtocolMessageType('Federation', (_message.Message,), {
  'DESCRIPTOR' : _FEDERATION,
  '__module__' : 'yandex.cloud.oauth.claims_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.oauth.Federation)
  })
_sym_db.RegisterMessage(Federation)


DESCRIPTOR._options = None
_SUBJECTCLAIMS.fields_by_name['sub']._options = None
_FEDERATION.fields_by_name['id']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v2/image.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ai/vision/v2/image.proto',
  package='yandex.cloud.ai.vision.v2',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;vision',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%yandex/cloud/ai/vision/v2/image.proto\x12\x19yandex.cloud.ai.vision.v2\"\xa5\x01\n\x05Image\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12>\n\nimage_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.ai.vision.v2.Image.ImageType\":\n\tImageType\x12\x1a\n\x16IMAGE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x07\n\x03PNG\x10\x02\x42\r\n\x0bImageSourceBe\n\x1dyandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;visionb\x06proto3'
)



_IMAGE_IMAGETYPE = _descriptor.EnumDescriptor(
  name='ImageType',
  full_name='yandex.cloud.ai.vision.v2.Image.ImageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IMAGE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JPEG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=161,
  serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_IMAGE_IMAGETYPE)


_IMAGE = _descriptor.Descriptor(
  name='Image',
  full_name='yandex.cloud.ai.vision.v2.Image',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='yandex.cloud.ai.vision.v2.Image.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_type', full_name='yandex.cloud.ai.vision.v2.Image.image_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IMAGE_IMAGETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ImageSource', full_name='yandex.cloud.ai.vision.v2.Image.ImageSource',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=69,
  serialized_end=234,
)

_IMAGE.fields_by_name['image_type'].enum_type = _IMAGE_IMAGETYPE
_IMAGE_IMAGETYPE.containing_type = _IMAGE
_IMAGE.oneofs_by_name['ImageSource'].fields.append(
  _IMAGE.fields_by_name['content'])
_IMAGE.fields_by_name['content'].containing_oneof = _IMAGE.oneofs_by_name['ImageSource']
DESCRIPTOR.message_types_by_name['Image'] = _IMAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'yandex.cloud.ai.vision.v2.image_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ai.vision.v2.Image)
  })
_sym_db.RegisterMessage(Image)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dns/v1/dns_zone_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.dns.v1 import dns_zone_pb2 as yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/dns/v1/dns_zone_service.proto',
  package='yandex.cloud.dns.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dns',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/dns/v1/dns_zone_service.proto\x12\x13yandex.cloud.dns.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/dns/v1/dns_zone.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\".\n\x11GetDnsZoneRequest\x12\x19\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x89\x01\n\x13ListDnsZonesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"`\n\x14ListDnsZonesResponse\x12/\n\tdns_zones\x18\x01 \x03(\x0b\x32\x1c.yandex.cloud.dns.v1.DnsZone\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8b\x04\n\x14\x43reateDnsZoneRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\x8a\xc8\x31\x04<=50\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x35.yandex.cloud.dns.v1.CreateDnsZoneRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x38\n\x04zone\x18\x05 \x01(\tB*\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=255\xf2\xc7\x31\x19[.]|[a-z0-9][-a-z0-9.]*\\.\x12\x42\n\x12private_visibility\x18\x06 \x01(\x0b\x32&.yandex.cloud.dns.v1.PrivateVisibility\x12@\n\x11public_visibility\x18\x07 \x01(\x0b\x32%.yandex.cloud.dns.v1.PublicVisibility\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\",\n\x15\x43reateDnsZoneMetadata\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\"\xfe\x03\n\x14UpdateDnsZoneRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8e\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.dns.v1.UpdateDnsZoneRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x42\n\x12private_visibility\x18\x06 \x01(\x0b\x32&.yandex.cloud.dns.v1.PrivateVisibility\x12@\n\x11public_visibility\x18\x07 \x01(\x0b\x32%.yandex.cloud.dns.v1.PublicVisibility\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\",\n\x15UpdateDnsZoneMetadata\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\"3\n\x14\x44\x65leteDnsZoneRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\",\n\x15\x44\x65leteDnsZoneMetadata\x12\x13\n\x0b\x64ns_zone_id\x18\x01 \x01(\t\"r\n\x1aGetDnsZoneRecordSetRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1b\n\x04name\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=255\x12\x1a\n\x04type\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=10\"\x96\x01\n\x1cListDnsZoneRecordSetsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x1dListDnsZoneRecordSetsResponse\x12\x33\n\x0brecord_sets\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb4\x01\n\x17UpdateRecordSetsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12=\n\tdeletions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\x12=\n\tadditions\x18\x03 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\"\x1a\n\x18UpdateRecordSetsMetadata\"\xf3\x01\n\x17UpsertRecordSetsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12=\n\tdeletions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\x12@\n\x0creplacements\x18\x03 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\x12:\n\x06merges\x18\x04 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSetB\n\x82\xc8\x31\x06<=1000\"\x1a\n\x18UpsertRecordSetsMetadata\"u\n\rRecordSetDiff\x12\x31\n\tadditions\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSet\x12\x31\n\tdeletions\x18\x02 \x03(\x0b\x32\x1e.yandex.cloud.dns.v1.RecordSet\"\x96\x01\n\x1cListDnsZoneOperationsRequest\x12\x1b\n\x0b\x64ns_zone_id\x18\x01 \x01(\tB\x06\x8a\xc8\x31\x02\x32\x30\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"o\n\x1dListDnsZoneOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe0\x11\n\x0e\x44nsZoneService\x12p\n\x03Get\x12&.yandex.cloud.dns.v1.GetDnsZoneRequest\x1a\x1c.yandex.cloud.dns.v1.DnsZone\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/dns/v1/zones/{dns_zone_id}\x12r\n\x04List\x12(.yandex.cloud.dns.v1.ListDnsZonesRequest\x1a).yandex.cloud.dns.v1.ListDnsZonesResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/dns/v1/zones\x12\x94\x01\n\x06\x43reate\x12).yandex.cloud.dns.v1.CreateDnsZoneRequest\x1a!.yandex.cloud.operation.Operation\"<\x82\xd3\xe4\x93\x02\x12\"\r/dns/v1/zones:\x01*\xb2\xd2* \n\x15\x43reateDnsZoneMetadata\x12\x07\x44nsZone\x12\xa2\x01\n\x06Update\x12).yandex.cloud.dns.v1.UpdateDnsZoneRequest\x1a!.yandex.cloud.operation.Operation\"J\x82\xd3\xe4\x93\x02 2\x1b/dns/v1/zones/{dns_zone_id}:\x01*\xb2\xd2* \n\x15UpdateDnsZoneMetadata\x12\x07\x44nsZone\x12\xad\x01\n\x06\x44\x65lete\x12).yandex.cloud.dns.v1.DeleteDnsZoneRequest\x1a!.yandex.cloud.operation.Operation\"U\x82\xd3\xe4\x93\x02\x1d*\x1b/dns/v1/zones/{dns_zone_id}\xb2\xd2*.\n\x15\x44\x65leteDnsZoneMetadata\x12\x15google.protobuf.Empty\x12\x91\x01\n\x0cGetRecordSet\x12/.yandex.cloud.dns.v1.GetDnsZoneRecordSetRequest\x1a\x1e.yandex.cloud.dns.v1.RecordSet\"0\x82\xd3\xe4\x93\x02*\x12(/dns/v1/zones/{dns_zone_id}:getRecordSet\x12\xab\x01\n\x0eListRecordSets\x12\x31.yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest\x1a\x32.yandex.cloud.dns.v1.ListDnsZoneRecordSetsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dns/v1/zones/{dns_zone_id}:listRecordSets\x12\xc9\x01\n\x10UpdateRecordSets\x12,.yandex.cloud.dns.v1.UpdateRecordSetsRequest\x1a!.yandex.cloud.operation.Operation\"d\x82\xd3\xe4\x93\x02\x31\",/dns/v1/zones/{dns_zone_id}:updateRecordSets:\x01*\xb2\xd2*)\n\x18UpdateRecordSetsMetadata\x12\rRecordSetDiff\x12\xc9\x01\n\x10UpsertRecordSets\x12,.yandex.cloud.dns.v1.UpsertRecordSetsRequest\x1a!.yandex.cloud.operation.Operation\"d\x82\xd3\xe4\x93\x02\x31\",/dns/v1/zones/{dns_zone_id}:upsertRecordSets:\x01*\xb2\xd2*)\n\x18UpsertRecordSetsMetadata\x12\rRecordSetDiff\x12\xa7\x01\n\x0eListOperations\x12\x31.yandex.cloud.dns.v1.ListDnsZoneOperationsRequest\x1a\x32.yandex.cloud.dns.v1.ListDnsZoneOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/dns/v1/zones/{dns_zone_id}/operations\x12\xad\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./dns/v1/zones/{resource_id}:listAccessBindings\x12\xdc\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"u\x82\xd3\xe4\x93\x02\x32\"-/dns/v1/zones/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xe8\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"{\x82\xd3\xe4\x93\x02\x35\"0/dns/v1/zones/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBV\n\x17yandex.cloud.api.dns.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1;dnsb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETDNSZONEREQUEST = _descriptor.Descriptor(
  name='GetDnsZoneRequest',
  full_name='yandex.cloud.dns.v1.GetDnsZoneRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.GetDnsZoneRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=352,
)


_LISTDNSZONESREQUEST = _descriptor.Descriptor(
  name='ListDnsZonesRequest',
  full_name='yandex.cloud.dns.v1.ListDnsZonesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.dns.v1.ListDnsZonesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.dns.v1.ListDnsZonesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.dns.v1.ListDnsZonesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.dns.v1.ListDnsZonesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=355,
  serialized_end=492,
)


_LISTDNSZONESRESPONSE = _descriptor.Descriptor(
  name='ListDnsZonesResponse',
  full_name='yandex.cloud.dns.v1.ListDnsZonesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zones', full_name='yandex.cloud.dns.v1.ListDnsZonesResponse.dns_zones', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.dns.v1.ListDnsZonesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=590,
)


_CREATEDNSZONEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1116,
)

_CREATEDNSZONEREQUEST = _descriptor.Descriptor(
  name='CreateDnsZoneRequest',
  full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.zone', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=255\362\3071\031[.]|[a-z0-9][-a-z0-9.]*\\.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_visibility', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.private_visibility', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_visibility', full_name='yandex.cloud.dns.v1.CreateDnsZoneRequest.public_visibility', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDNSZONEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=1116,
)


_CREATEDNSZONEMETADATA = _descriptor.Descriptor(
  name='CreateDnsZoneMetadata',
  full_name='yandex.cloud.dns.v1.CreateDnsZoneMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.CreateDnsZoneMetadata.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1162,
)


_UPDATEDNSZONEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1116,
)

_UPDATEDNSZONEREQUEST = _descriptor.Descriptor(
  name='UpdateDnsZoneRequest',
  full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\00220', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_visibility', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.private_visibility', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public_visibility', full_name='yandex.cloud.dns.v1.UpdateDnsZoneRequest.public_visibility', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEDNSZONEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1675,
)


_UPDATEDNSZONEMETADATA = _descriptor.Descriptor(
  name='UpdateDnsZoneMetadata',
  full_name='yandex.cloud.dns.v1.UpdateDnsZoneMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.UpdateDnsZoneMetadata.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1721,
)


_DELETEDNSZONEREQUEST = _descriptor.Descriptor(
  name='DeleteDnsZoneRequest',
  full_name='yandex.cloud.dns.v1.DeleteDnsZoneRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.DeleteDnsZoneRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\00220', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1723,
  serialized_end=1774,
)


_DELETEDNSZONEMETADATA = _descriptor.Descriptor(
  name='DeleteDnsZoneMetadata',
  full_name='yandex.cloud.dns.v1.DeleteDnsZoneMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.DeleteDnsZoneMetadata.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1776,
  serialized_end=1820,
)


_GETDNSZONERECORDSETREQUEST = _descriptor.Descriptor(
  name='GetDnsZoneRecordSetRequest',
  full_name='yandex.cloud.dns.v1.GetDnsZoneRecordSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.GetDnsZoneRecordSetRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\00220', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.dns.v1.GetDnsZoneRecordSetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\005<=255', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.dns.v1.GetDnsZoneRecordSetRequest.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1936,
)


_LISTDNSZONERECORDSETSREQUEST = _descriptor.Descriptor(
  name='ListDnsZoneRecordSetsRequest',
  full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\00220', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1939,
  serialized_end=2089,
)


_LISTDNSZONERECORDSETSRESPONSE = _descriptor.Descriptor(
  name='ListDnsZoneRecordSetsResponse',
  full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='record_sets', full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsResponse.record_sets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.dns.v1.ListDnsZoneRecordSetsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2091,
  serialized_end=2200,
)


_UPDATERECORDSETSREQUEST = _descriptor.Descriptor(
  name='UpdateRecordSetsRequest',
  full_name='yandex.cloud.dns.v1.UpdateRecordSetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.UpdateRecordSetsRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\00220', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletions', full_name='yandex.cloud.dns.v1.UpdateRecordSetsRequest.deletions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additions', full_name='yandex.cloud.dns.v1.UpdateRecordSetsRequest.additions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2203,
  serialized_end=2383,
)


_UPDATERECORDSETSMETADATA = _descriptor.Descriptor(
  name='UpdateRecordSetsMetadata',
  full_name='yandex.cloud.dns.v1.UpdateRecordSetsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2385,
  serialized_end=2411,
)


_UPSERTRECORDSETSREQUEST = _descriptor.Descriptor(
  name='UpsertRecordSetsRequest',
  full_name='yandex.cloud.dns.v1.UpsertRecordSetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.UpsertRecordSetsRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\00220', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletions', full_name='yandex.cloud.dns.v1.UpsertRecordSetsRequest.deletions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replacements', full_name='yandex.cloud.dns.v1.UpsertRecordSetsRequest.replacements', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merges', full_name='yandex.cloud.dns.v1.UpsertRecordSetsRequest.merges', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2414,
  serialized_end=2657,
)


_UPSERTRECORDSETSMETADATA = _descriptor.Descriptor(
  name='UpsertRecordSetsMetadata',
  full_name='yandex.cloud.dns.v1.UpsertRecordSetsMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2659,
  serialized_end=2685,
)


_RECORDSETDIFF = _descriptor.Descriptor(
  name='RecordSetDiff',
  full_name='yandex.cloud.dns.v1.RecordSetDiff',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='additions', full_name='yandex.cloud.dns.v1.RecordSetDiff.additions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deletions', full_name='yandex.cloud.dns.v1.RecordSetDiff.deletions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2687,
  serialized_end=2804,
)


_LISTDNSZONEOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListDnsZoneOperationsRequest',
  full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsRequest.dns_zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\00220', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2807,
  serialized_end=2957,
)


_LISTDNSZONEOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListDnsZoneOperationsResponse',
  full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.dns.v1.ListDnsZoneOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2959,
  serialized_end=3070,
)

_LISTDNSZONESRESPONSE.fields_by_name['dns_zones'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._DNSZONE
_CREATEDNSZONEREQUEST_LABELSENTRY.containing_type = _CREATEDNSZONEREQUEST
_CREATEDNSZONEREQUEST.fields_by_name['labels'].message_type = _CREATEDNSZONEREQUEST_LABELSENTRY
_CREATEDNSZONEREQUEST.fields_by_name['private_visibility'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._PRIVATEVISIBILITY
_CREATEDNSZONEREQUEST.fields_by_name['public_visibility'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._PUBLICVISIBILITY
_UPDATEDNSZONEREQUEST_LABELSENTRY.containing_type = _UPDATEDNSZONEREQUEST
_UPDATEDNSZONEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEDNSZONEREQUEST.fields_by_name['labels'].message_type = _UPDATEDNSZONEREQUEST_LABELSENTRY
_UPDATEDNSZONEREQUEST.fields_by_name['private_visibility'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._PRIVATEVISIBILITY
_UPDATEDNSZONEREQUEST.fields_by_name['public_visibility'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._PUBLICVISIBILITY
_LISTDNSZONERECORDSETSRESPONSE.fields_by_name['record_sets'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_UPDATERECORDSETSREQUEST.fields_by_name['deletions'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_UPDATERECORDSETSREQUEST.fields_by_name['additions'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_UPSERTRECORDSETSREQUEST.fields_by_name['deletions'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_UPSERTRECORDSETSREQUEST.fields_by_name['replacements'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_UPSERTRECORDSETSREQUEST.fields_by_name['merges'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_RECORDSETDIFF.fields_by_name['additions'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_RECORDSETDIFF.fields_by_name['deletions'].message_type = yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET
_LISTDNSZONEOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetDnsZoneRequest'] = _GETDNSZONEREQUEST
DESCRIPTOR.message_types_by_name['ListDnsZonesRequest'] = _LISTDNSZONESREQUEST
DESCRIPTOR.message_types_by_name['ListDnsZonesResponse'] = _LISTDNSZONESRESPONSE
DESCRIPTOR.message_types_by_name['CreateDnsZoneRequest'] = _CREATEDNSZONEREQUEST
DESCRIPTOR.message_types_by_name['CreateDnsZoneMetadata'] = _CREATEDNSZONEMETADATA
DESCRIPTOR.message_types_by_name['UpdateDnsZoneRequest'] = _UPDATEDNSZONEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDnsZoneMetadata'] = _UPDATEDNSZONEMETADATA
DESCRIPTOR.message_types_by_name['DeleteDnsZoneRequest'] = _DELETEDNSZONEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDnsZoneMetadata'] = _DELETEDNSZONEMETADATA
DESCRIPTOR.message_types_by_name['GetDnsZoneRecordSetRequest'] = _GETDNSZONERECORDSETREQUEST
DESCRIPTOR.message_types_by_name['ListDnsZoneRecordSetsRequest'] = _LISTDNSZONERECORDSETSREQUEST
DESCRIPTOR.message_types_by_name['ListDnsZoneRecordSetsResponse'] = _LISTDNSZONERECORDSETSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRecordSetsRequest'] = _UPDATERECORDSETSREQUEST
DESCRIPTOR.message_types_by_name['UpdateRecordSetsMetadata'] = _UPDATERECORDSETSMETADATA
DESCRIPTOR.message_types_by_name['UpsertRecordSetsRequest'] = _UPSERTRECORDSETSREQUEST
DESCRIPTOR.message_types_by_name['UpsertRecordSetsMetadata'] = _UPSERTRECORDSETSMETADATA
DESCRIPTOR.message_types_by_name['RecordSetDiff'] = _RECORDSETDIFF
DESCRIPTOR.message_types_by_name['ListDnsZoneOperationsRequest'] = _LISTDNSZONEOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListDnsZoneOperationsResponse'] = _LISTDNSZONEOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDnsZoneRequest = _reflection.GeneratedProtocolMessageType('GetDnsZoneRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDNSZONEREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.GetDnsZoneRequest)
  })
_sym_db.RegisterMessage(GetDnsZoneRequest)

ListDnsZonesRequest = _reflection.GeneratedProtocolMessageType('ListDnsZonesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDNSZONESREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.ListDnsZonesRequest)
  })
_sym_db.RegisterMessage(ListDnsZonesRequest)

ListDnsZonesResponse = _reflection.GeneratedProtocolMessageType('ListDnsZonesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDNSZONESRESPONSE,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.ListDnsZonesResponse)
  })
_sym_db.RegisterMessage(ListDnsZonesResponse)

CreateDnsZoneRequest = _reflection.GeneratedProtocolMessageType('CreateDnsZoneRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDNSZONEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.CreateDnsZoneRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDNSZONEREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.CreateDnsZoneRequest)
  })
_sym_db.RegisterMessage(CreateDnsZoneRequest)
_sym_db.RegisterMessage(CreateDnsZoneRequest.LabelsEntry)

CreateDnsZoneMetadata = _reflection.GeneratedProtocolMessageType('CreateDnsZoneMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDNSZONEMETADATA,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.CreateDnsZoneMetadata)
  })
_sym_db.RegisterMessage(CreateDnsZoneMetadata)

UpdateDnsZoneRequest = _reflection.GeneratedProtocolMessageType('UpdateDnsZoneRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEDNSZONEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.UpdateDnsZoneRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEDNSZONEREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.UpdateDnsZoneRequest)
  })
_sym_db.RegisterMessage(UpdateDnsZoneRequest)
_sym_db.RegisterMessage(UpdateDnsZoneRequest.LabelsEntry)

UpdateDnsZoneMetadata = _reflection.GeneratedProtocolMessageType('UpdateDnsZoneMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDNSZONEMETADATA,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.UpdateDnsZoneMetadata)
  })
_sym_db.RegisterMessage(UpdateDnsZoneMetadata)

DeleteDnsZoneRequest = _reflection.GeneratedProtocolMessageType('DeleteDnsZoneRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDNSZONEREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.DeleteDnsZoneRequest)
  })
_sym_db.RegisterMessage(DeleteDnsZoneRequest)

DeleteDnsZoneMetadata = _reflection.GeneratedProtocolMessageType('DeleteDnsZoneMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDNSZONEMETADATA,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.DeleteDnsZoneMetadata)
  })
_sym_db.RegisterMessage(DeleteDnsZoneMetadata)

GetDnsZoneRecordSetRequest = _reflection.GeneratedProtocolMessageType('GetDnsZoneRecordSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDNSZONERECORDSETREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.GetDnsZoneRecordSetRequest)
  })
_sym_db.RegisterMessage(GetDnsZoneRecordSetRequest)

ListDnsZoneRecordSetsRequest = _reflection.GeneratedProtocolMessageType('ListDnsZoneRecordSetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDNSZONERECORDSETSREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.ListDnsZoneRecordSetsRequest)
  })
_sym_db.RegisterMessage(ListDnsZoneRecordSetsRequest)

ListDnsZoneRecordSetsResponse = _reflection.GeneratedProtocolMessageType('ListDnsZoneRecordSetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDNSZONERECORDSETSRESPONSE,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.ListDnsZoneRecordSetsResponse)
  })
_sym_db.RegisterMessage(ListDnsZoneRecordSetsResponse)

UpdateRecordSetsRequest = _reflection.GeneratedProtocolMessageType('UpdateRecordSetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECORDSETSREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.UpdateRecordSetsRequest)
  })
_sym_db.RegisterMessage(UpdateRecordSetsRequest)

UpdateRecordSetsMetadata = _reflection.GeneratedProtocolMessageType('UpdateRecordSetsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECORDSETSMETADATA,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.UpdateRecordSetsMetadata)
  })
_sym_db.RegisterMessage(UpdateRecordSetsMetadata)

UpsertRecordSetsRequest = _reflection.GeneratedProtocolMessageType('UpsertRecordSetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPSERTRECORDSETSREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.UpsertRecordSetsRequest)
  })
_sym_db.RegisterMessage(UpsertRecordSetsRequest)

UpsertRecordSetsMetadata = _reflection.GeneratedProtocolMessageType('UpsertRecordSetsMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPSERTRECORDSETSMETADATA,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.UpsertRecordSetsMetadata)
  })
_sym_db.RegisterMessage(UpsertRecordSetsMetadata)

RecordSetDiff = _reflection.GeneratedProtocolMessageType('RecordSetDiff', (_message.Message,), {
  'DESCRIPTOR' : _RECORDSETDIFF,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.RecordSetDiff)
  })
_sym_db.RegisterMessage(RecordSetDiff)

ListDnsZoneOperationsRequest = _reflection.GeneratedProtocolMessageType('ListDnsZoneOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDNSZONEOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.ListDnsZoneOperationsRequest)
  })
_sym_db.RegisterMessage(ListDnsZoneOperationsRequest)

ListDnsZoneOperationsResponse = _reflection.GeneratedProtocolMessageType('ListDnsZoneOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDNSZONEOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.dns.v1.dns_zone_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.dns.v1.ListDnsZoneOperationsResponse)
  })
_sym_db.RegisterMessage(ListDnsZoneOperationsResponse)


DESCRIPTOR._options = None
_GETDNSZONEREQUEST.fields_by_name['dns_zone_id']._options = None
_LISTDNSZONESREQUEST.fields_by_name['folder_id']._options = None
_LISTDNSZONESREQUEST.fields_by_name['page_size']._options = None
_LISTDNSZONESREQUEST.fields_by_name['page_token']._options = None
_LISTDNSZONESREQUEST.fields_by_name['filter']._options = None
_CREATEDNSZONEREQUEST_LABELSENTRY._options = None
_CREATEDNSZONEREQUEST.fields_by_name['folder_id']._options = None
_CREATEDNSZONEREQUEST.fields_by_name['name']._options = None
_CREATEDNSZONEREQUEST.fields_by_name['description']._options = None
_CREATEDNSZONEREQUEST.fields_by_name['labels']._options = None
_CREATEDNSZONEREQUEST.fields_by_name['zone']._options = None
_UPDATEDNSZONEREQUEST_LABELSENTRY._options = None
_UPDATEDNSZONEREQUEST.fields_by_name['dns_zone_id']._options = None
_UPDATEDNSZONEREQUEST.fields_by_name['name']._options = None
_UPDATEDNSZONEREQUEST.fields_by_name['description']._options = None
_UPDATEDNSZONEREQUEST.fields_by_name['labels']._options = None
_DELETEDNSZONEREQUEST.fields_by_name['dns_zone_id']._options = None
_GETDNSZONERECORDSETREQUEST.fields_by_name['dns_zone_id']._options = None
_GETDNSZONERECORDSETREQUEST.fields_by_name['name']._options = None
_GETDNSZONERECORDSETREQUEST.fields_by_name['type']._options = None
_LISTDNSZONERECORDSETSREQUEST.fields_by_name['dns_zone_id']._options = None
_LISTDNSZONERECORDSETSREQUEST.fields_by_name['page_size']._options = None
_LISTDNSZONERECORDSETSREQUEST.fields_by_name['page_token']._options = None
_LISTDNSZONERECORDSETSREQUEST.fields_by_name['filter']._options = None
_UPDATERECORDSETSREQUEST.fields_by_name['dns_zone_id']._options = None
_UPDATERECORDSETSREQUEST.fields_by_name['deletions']._options = None
_UPDATERECORDSETSREQUEST.fields_by_name['additions']._options = None
_UPSERTRECORDSETSREQUEST.fields_by_name['dns_zone_id']._options = None
_UPSERTRECORDSETSREQUEST.fields_by_name['deletions']._options = None
_UPSERTRECORDSETSREQUEST.fields_by_name['replacements']._options = None
_UPSERTRECORDSETSREQUEST.fields_by_name['merges']._options = None
_LISTDNSZONEOPERATIONSREQUEST.fields_by_name['dns_zone_id']._options = None
_LISTDNSZONEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTDNSZONEOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTDNSZONEOPERATIONSREQUEST.fields_by_name['filter']._options = None

_DNSZONESERVICE = _descriptor.ServiceDescriptor(
  name='DnsZoneService',
  full_name='yandex.cloud.dns.v1.DnsZoneService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3073,
  serialized_end=5345,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.dns.v1.DnsZoneService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDNSZONEREQUEST,
    output_type=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._DNSZONE,
    serialized_options=b'\202\323\344\223\002\035\022\033/dns/v1/zones/{dns_zone_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.dns.v1.DnsZoneService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDNSZONESREQUEST,
    output_type=_LISTDNSZONESRESPONSE,
    serialized_options=b'\202\323\344\223\002\017\022\r/dns/v1/zones',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.dns.v1.DnsZoneService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDNSZONEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\022\"\r/dns/v1/zones:\001*\262\322* \n\025CreateDnsZoneMetadata\022\007DnsZone',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.dns.v1.DnsZoneService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEDNSZONEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 2\033/dns/v1/zones/{dns_zone_id}:\001*\262\322* \n\025UpdateDnsZoneMetadata\022\007DnsZone',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.dns.v1.DnsZoneService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEDNSZONEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/dns/v1/zones/{dns_zone_id}\262\322*.\n\025DeleteDnsZoneMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecordSet',
    full_name='yandex.cloud.dns.v1.DnsZoneService.GetRecordSet',
    index=5,
    containing_service=None,
    input_type=_GETDNSZONERECORDSETREQUEST,
    output_type=yandex_dot_cloud_dot_dns_dot_v1_dot_dns__zone__pb2._RECORDSET,
    serialized_options=b'\202\323\344\223\002*\022(/dns/v1/zones/{dns_zone_id}:getRecordSet',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRecordSets',
    full_name='yandex.cloud.dns.v1.DnsZoneService.ListRecordSets',
    index=6,
    containing_service=None,
    input_type=_LISTDNSZONERECORDSETSREQUEST,
    output_type=_LISTDNSZONERECORDSETSRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/dns/v1/zones/{dns_zone_id}:listRecordSets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRecordSets',
    full_name='yandex.cloud.dns.v1.DnsZoneService.UpdateRecordSets',
    index=7,
    containing_service=None,
    input_type=_UPDATERECORDSETSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021\",/dns/v1/zones/{dns_zone_id}:updateRecordSets:\001*\262\322*)\n\030UpdateRecordSetsMetadata\022\rRecordSetDiff',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpsertRecordSets',
    full_name='yandex.cloud.dns.v1.DnsZoneService.UpsertRecordSets',
    index=8,
    containing_service=None,
    input_type=_UPSERTRECORDSETSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021\",/dns/v1/zones/{dns_zone_id}:upsertRecordSets:\001*\262\322*)\n\030UpsertRecordSetsMetadata\022\rRecordSetDiff',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.dns.v1.DnsZoneService.ListOperations',
    index=9,
    containing_service=None,
    input_type=_LISTDNSZONEOPERATIONSREQUEST,
    output_type=_LISTDNSZONEOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/dns/v1/zones/{dns_zone_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.dns.v1.DnsZoneService.ListAccessBindings',
    index=10,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./dns/v1/zones/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.dns.v1.DnsZoneService.SetAccessBindings',
    index=11,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0022\"-/dns/v1/zones/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.dns.v1.DnsZoneService.UpdateAccessBindings',
    index=12,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0025\"0/dns/v1/zones/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DNSZONESERVICE)

DESCRIPTOR.services_by_name['DnsZoneService'] = _DNSZONESERVICE

# @@protoc_insertion_point(module_scope)
